@@ -1,10 +1,10 @@
 /*
     requestfactory.h - Kopete Groupwise Protocol
-  
-    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
+
+    Copyright (c) 2004      SUSE Linux AG	     http://www.suse.com
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
- 
+
     *************************************************************************
     *                                                                       *
     * This library is free software; you can redistribute it and/or         *
@@ -23,22 +23,23 @@
 class Request;
 
 /**
- * Factory for obtaining @ref Request instances.  
+ * Factory for obtaining @ref Request instances.
  * @author Kopete Developers
  */
-class RequestFactory{
+class RequestFactory
+{
 public:
-	RequestFactory();
-	~RequestFactory();
-	
-	/**
-	 * Obtain a new @ref Request instance
-	 * The consumer is responsible for deleting this
-	 * TODO: Allow the user to provide the fields for the request in this call
-	 */
-	Request * request( const QString &request);
+    RequestFactory();
+    ~RequestFactory();
+
+    /**
+     * Obtain a new @ref Request instance
+     * The consumer is responsible for deleting this
+     * TODO: Allow the user to provide the fields for the request in this call
+     */
+    Request *request(const QString &request);
 private:
-	int m_nextTransaction;
+    int m_nextTransaction;
 };
 
 #endif
